# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ContentType(str, enum.Enum):
    """
    * `STRING` - STRING
    * `JSON` - JSON
    """

    STRING = "STRING"
    JSON = "JSON"

    def visit(self, string: typing.Callable[[], T_Result], json: typing.Callable[[], T_Result]) -> T_Result:
        if self is ContentType.STRING:
            return string()
        if self is ContentType.JSON:
            return json()
