# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .metadata_filter_rule_combinator import MetadataFilterRuleCombinator
from .metadata_filter_rule_request import MetadataFilterRuleRequest


class MetadataFilterConfigRequest(pydantic.BaseModel):
    combinator: typing.Optional[MetadataFilterRuleCombinator]
    negated: typing.Optional[bool]
    rules: typing.Optional[typing.List[MetadataFilterRuleRequest]]
    field: typing.Optional[str] = pydantic.Field(description='<span style="white-space: nowrap">`non-empty`</span>')
    operator: typing.Optional[str] = pydantic.Field(description='<span style="white-space: nowrap">`non-empty`</span>')
    value: typing.Optional[str] = pydantic.Field(description='<span style="white-space: nowrap">`non-empty`</span>')

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
