# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .logprobs_enum import LogprobsEnum


class GenerateOptionsRequest(pydantic.BaseModel):
    logprobs: typing.Optional[LogprobsEnum] = pydantic.Field(
        description=(
            "Which logprobs to include, if any. Defaults to NONE.\n" "\n" "* `ALL` - ALL\n" "* `NONE` - NONE\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
